@@ -5,17 +5,17 @@ from .anonymizer import (
     unpickle_anonymizer,
 )
 from .anonymizer_server import (
-    FitResource,
     InferenceResource,
     supervised_learning_anonymizer_server_factory,
+    validate_anonymizer_input_or_raise,
 )
 
 __all__ = [
-    "FitResource",
     "InferenceResource",
     "pickle_anonymizer",
     "supervised_learning_anonymizer_server_factory",
     "SupervisedLearningAnonymizer",
     "unpickle_anonymizer",
+    "validate_anonymizer_input_or_raise",
     "WrappedAnonymizer",
 ]
