@@ -66,7 +66,7 @@ class SupervisedLearningAnonymizer(ABC):
         pass
 
     @abstractmethod
-    def validate_input(self, input_array: np.ndarray) -> None:
+    def validate_input(self, feature_array: np.ndarray) -> None:
         """Check whether the input array is a valid argument for `fit` and for
         `predict (parameter `X`).
 
@@ -74,13 +74,13 @@ class SupervisedLearningAnonymizer(ABC):
 
         Parameters
         ----------
-        input_array : np.ndarray
-            The array to validate.
+        feature_array : np.ndarray
+            The input feature array to validate.
 
         Raises
         ------
         ValueError
-            If `input_array` is incompatible with this anonymizer.
+            If `feature_array` is incompatible with this anonymizer.
         """
         pass
 
@@ -96,7 +96,7 @@ class WrappedAnonymizer(SupervisedLearningAnonymizer):
         self,
         anonymizer,
         serializer: Callable[[Any, str | Path], None] | None = None,
-        input_array_validator: Callable[[np.ndarray], None] | None = None,
+        feature_array_validator: Callable[[np.ndarray], None] | None = None,
     ) -> None:
         """
         Parameters
@@ -111,8 +111,8 @@ class WrappedAnonymizer(SupervisedLearningAnonymizer):
             `save` method. The first argument of the serializer is `anonymizer`
             and the second the filepath. By default `None`, which means
             invoking `anonymizer.save(...)`.
-        input_array_validator : Callable[[np.ndarray], None] | None, optional
-            The array input validator to use, if `anonymizer` does not provide
+        feature_array_validator : Callable[[np.ndarray], None] | None, optional
+            The feature array validator to use, if `anonymizer` does not provide
             a `validate_input` method. By default `None`, which means invoking
             `anonymizer.validate_input(...)`.
 
@@ -132,7 +132,7 @@ class WrappedAnonymizer(SupervisedLearningAnonymizer):
         self._anonymizer = anonymizer
 
         self._serialize = serializer
-        self._validate = input_array_validator
+        self._validate = feature_array_validator
 
     def fit(self, X: np.ndarray, y: np.ndarray):
         self._anonymizer.fit(X, y)
@@ -175,11 +175,11 @@ class WrappedAnonymizer(SupervisedLearningAnonymizer):
                 "replacement is also missing."
             )
 
-    def validate_input(self, input_array: np.ndarray) -> None:
+    def validate_input(self, feature_array: np.ndarray) -> None:
         if hasattr(self._anonymizer, "validate_input"):
-            self._anonymizer.validate_input(input_array)
+            self._anonymizer.validate_input(feature_array)
         elif self._validate is not None:
-            self._validate(input_array)
+            self._validate(feature_array)
         else:
             raise NotImplementedError(
                 "Anonymizer object does not provide a validate_input function "
