@@ -83,7 +83,7 @@ def test_WrappedAnonymizer(
         anonymizer.WrappedAnonymizer(
             partial_dummy_anonymizer,
             serializer=anonymizer.pickle_anonymizer,
-            input_array_validator=lambda _: None,
+            feature_array_validator=lambda _: None,
         ),
     ]:
         wrapped_anon.fit(ten_elem_ndarray, ten_elem_ndarray)
